@@ -67,6 +67,10 @@ class RedisClient():
         return dict(zip(keys, self.get_values_from_keys(keys)))
 
 
+    def get_value_from_key(self, key: str) -> dict:
+        """ Returns the value for the given key """
+        return self.engine.hgetall(key)
+
     def get_values_from_keys(self, keys: list) -> list:
         """ Returns the values for the given keys """
         with self.engine.pipeline() as pipe:
